<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Duplicate</name>
    <message>
        <location filename="../DuplicateInit.js" line="+2"/>
        <source>&amp;Duplicate</source>
        <translation>&amp;Dupliquer</translation>
    </message>
    <message>
        <source>1 entity duplicated</source>
        <translation type="vanished">Une entité a été dupliqué</translation>
    </message>
    <message>
        <source>%1 entities duplicated</source>
        <translation type="vanished">%1 entités ont été dupliqués</translation>
    </message>
    <message numerus="yes">
        <location filename="../Duplicate.js" line="+54"/>
        <source>%n entity/ies duplicated</source>
        <translation>
            <numerusform>%n entité a été dupliqué</numerusform>
            <numerusform>%n entités ont été dupliqués</numerusform>
        </translation>
    </message>
</context>
</TS>
